Welcome to the official FinderZ Library documentation!
======================================================

**FinderZ**

Full file management library for Python

V2 is out, go check out the changes made under :doc:`updatev2`!

.. note::

   I am not responsible for any damage or data lost done by this library. I have added warnings where there may be potential data loss, and how to avoid it.

.. image:: img/logo-color.jpg

.. raw:: html

   <p align="center">
       <img src="https://img.shields.io/badge/Creator-PatzEdi-brightgreen.svg" alt="Badge 1" width="100">
       <img src="https://img.shields.io/badge/Version-2-brightgreen.svg" alt="Badge 2" width="100">
       <img src="https://img.shields.io/badge/License-MIT-brightgreen.svg" alt="Badge 3" width="100">
       <img src="https://static.pepy.tech/badge/finderz" alt="Badge 4" width="100">
       
   </p>


.. note::

   This documentation could change as time passes in case something gets edited or changed.

Index
=====

.. toctree::
   updatev2
   installation
   code structure
   function use
   credits
   